@@ -1,16 +1,16 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# In[6]:
+# In[10]:
+
 
 
-class remfunc:
     
-    import socket, pickle
+import socket, pickle
     
     
     
-    def start_server(host,port,debug = False):
+def start_server(host,port,debug = False):
         
         
         if debug == True:
@@ -74,26 +74,38 @@ class remfunc:
                 pass
     
 
-    class client:
+HOST = ""
+PORT = 0
+ini = False
         
-        def __init__(self, HOST,PORT):
+def init(h,p):
+    
+    global HOST
+    global PORT
+    global init
+    ini = True
+    
+    HOST = h
+    PORT = p
+    
+
+                
                 
-                self.HOST = HOST
-                self.PORT = PORT
-                self.init = True
        
             
-        def do(self,code):
+def do(code):
             
             import socket, pickle
             
             
-            HOST = self.HOST
-            PORT = self.PORT
+            global HOST
+            global PORT
+            global ini
+           
                 
-            if self.init == False:
+            if ini == False:
                 
-                raise RuntimeError("Client not initialized, create class instance with instancename = remfunc.client(HOST,PORT) first. You only need to do this once.")
+                raise RuntimeError("Client not initialized, run remfunc.init(HOST,PORT) first. You only need to do this once.")
             
             s = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
             
@@ -165,7 +177,7 @@ class remfunc:
             
             
             
-            
+         
             
         
         
